summaryrefslogtreecommitdiffstats
path: root/include/LibreOfficeKit/LibreOfficeKit.hxx
diff options
context:
space:
mode:
authorMichael Meeks <michael.meeks@collabora.com>2019-07-20 10:43:39 +0100
committerMichael Meeks <michael.meeks@collabora.com>2019-08-02 11:41:48 -0400
commitf59e986d0dc04a2d62cc1f236acedfcf727449ce (patch)
treed4739978f593ba969cac9467f1d87e5c1a109186 /include/LibreOfficeKit/LibreOfficeKit.hxx
parentbuild fix: missing #include <ndgrf.hxx> (diff)
downloadcore-f59e986d0dc04a2d62cc1f236acedfcf727449ce.tar.gz
core-f59e986d0dc04a2d62cc1f236acedfcf727449ce.zip
lok: clipboard: per view clipboard creation.
A bit brutal, but the mess around clipboard instantiation is awful. Change-Id: I62d6af8bf6813e6bab81123417ea8bfb28394e29
Diffstat (limited to 'include/LibreOfficeKit/LibreOfficeKit.hxx')
-rw-r--r--include/LibreOfficeKit/LibreOfficeKit.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/LibreOfficeKit/LibreOfficeKit.hxx b/include/LibreOfficeKit/LibreOfficeKit.hxx
index f38d2b5109f6..bd6609c321a4 100644
--- a/include/LibreOfficeKit/LibreOfficeKit.hxx
+++ b/include/LibreOfficeKit/LibreOfficeKit.hxx
@@ -362,7 +362,7 @@ public:
}
/**
* Gets the selected content for the current view as a series of binary streams.
*
* NB. returns a complete set of possible selection types if nullptr is passed for pMimeTypes.
*
@@ -374,13 +374,13 @@ public:
*
* @returns: true on success, false on error.
*/
- bool getSelection(const char **pMimeTypes,
+ bool getClipboard(const char **pMimeTypes,
size_t *pOutCount,
char ***pOutMimeTypes,
size_t **pOutSizes,
char ***pOutStreams)
{
- return mpDoc->pClass->getSelection(mpDoc, pMimeTypes, pOutCount, pOutMimeTypes, pOutSizes, pOutStreams);
+ return mpDoc->pClass->getClipboard(mpDoc, pMimeTypes, pOutCount, pOutMimeTypes, pOutSizes, pOutStreams);
}
/**
@@ -362,7 +362,7 @@ public:
}
/**
- * Gets the selected content for the current view as a series of binary streams.
+ * Gets the content on the clipboard for the current view as a series of binary streams.
*
* NB. returns a complete set of possible selection types if nullptr is passed for pMimeTypes.